from enum import Enum


# noinspection SpellCheckingInspection
class AregAttRcsKeepConst(Enum):
	"""2 Members, ATTenuation ... RCS"""
	ATTenuation = 0
	RCS = 1


# noinspection SpellCheckingInspection
class AregCableCorrSour(Enum):
	"""2 Members, S2P ... USER"""
	S2P = 0
	USER = 1


# noinspection SpellCheckingInspection
class AregCconfigBw(Enum):
	"""3 Members, BW1G ... BW5G"""
	BW1G = 0
	BW2G = 1
	BW5G = 2


# noinspection SpellCheckingInspection
class AregCconfigOptMode(Enum):
	"""2 Members, FAST ... QHIG"""
	FAST = 0
	QHIG = 1


# noinspection SpellCheckingInspection
class AregCconfigSystAlign(Enum):
	"""2 Members, OFF ... TABLe"""
	OFF = 0
	TABLe = 1


# noinspection SpellCheckingInspection
class AregChanMappingGui(Enum):
	"""70 Members, IFONly ... TRX4"""
	IFONly = 0
	NONE = 1
	QAT1CH1 = 2
	QAT1CH2 = 3
	QAT1CH3 = 4
	QAT1CH4 = 5
	QAT1CH5 = 6
	QAT1CH6 = 7
	QAT1CH7 = 8
	QAT1CH8 = 9
	QAT2CH1 = 10
	QAT2CH2 = 11
	QAT2CH3 = 12
	QAT2CH4 = 13
	QAT2CH5 = 14
	QAT2CH6 = 15
	QAT2CH7 = 16
	QAT2CH8 = 17
	QAT3CH1 = 18
	QAT3CH2 = 19
	QAT3CH3 = 20
	QAT3CH4 = 21
	QAT3CH5 = 22
	QAT3CH6 = 23
	QAT3CH7 = 24
	QAT3CH8 = 25
	QAT4CH1 = 26
	QAT4CH2 = 27
	QAT4CH3 = 28
	QAT4CH4 = 29
	QAT4CH5 = 30
	QAT4CH6 = 31
	QAT4CH7 = 32
	QAT4CH8 = 33
	QAT5CH1 = 34
	QAT5CH2 = 35
	QAT5CH3 = 36
	QAT5CH4 = 37
	QAT5CH5 = 38
	QAT5CH6 = 39
	QAT5CH7 = 40
	QAT5CH8 = 41
	QAT6CH1 = 42
	QAT6CH2 = 43
	QAT6CH3 = 44
	QAT6CH4 = 45
	QAT6CH5 = 46
	QAT6CH6 = 47
	QAT6CH7 = 48
	QAT6CH8 = 49
	QAT7CH1 = 50
	QAT7CH2 = 51
	QAT7CH3 = 52
	QAT7CH4 = 53
	QAT7CH5 = 54
	QAT7CH6 = 55
	QAT7CH7 = 56
	QAT7CH8 = 57
	QAT8CH1 = 58
	QAT8CH2 = 59
	QAT8CH3 = 60
	QAT8CH4 = 61
	QAT8CH5 = 62
	QAT8CH6 = 63
	QAT8CH7 = 64
	QAT8CH8 = 65
	TRX1 = 66
	TRX2 = 67
	TRX3 = 68
	TRX4 = 69


# noinspection SpellCheckingInspection
class AregChanMappingSensor(Enum):
	"""9 Members, NONE ... SEN8"""
	NONE = 0
	SEN1 = 1
	SEN2 = 2
	SEN3 = 3
	SEN4 = 4
	SEN5 = 5
	SEN6 = 6
	SEN7 = 7
	SEN8 = 8


# noinspection SpellCheckingInspection
class AregDopplerUnit(Enum):
	"""2 Members, FREQuency ... SPEed"""
	FREQuency = 0
	SPEed = 1


# noinspection SpellCheckingInspection
class AregDynLoggLevel(Enum):
	"""3 Members, ALL ... ERRor"""
	ALL = 0
	EAWarning = 1
	ERRor = 2


# noinspection SpellCheckingInspection
class AregDynLoggTimeBase(Enum):
	"""2 Members, SIMulation ... SYSTem"""
	SIMulation = 0
	SYSTem = 1


# noinspection SpellCheckingInspection
class AregFeQatConnMode(Enum):
	"""6 Members, CERRor ... UPDate"""
	CERRor = 0
	CONNected = 1
	DIALing = 2
	DISConnected = 3
	UERRor = 4
	UPDate = 5


# noinspection SpellCheckingInspection
class AregFeQatMode(Enum):
	"""2 Members, MULTi ... SINGle"""
	MULTi = 0
	SINGle = 1


# noinspection SpellCheckingInspection
class AregFeType(Enum):
	"""3 Members, NONE ... TRX"""
	NONE = 0
	QAT = 1
	TRX = 2


# noinspection SpellCheckingInspection
class AregMeasPort(Enum):
	"""2 Members, AUX ... POW"""
	AUX = 0
	POW = 1


# noinspection SpellCheckingInspection
class AregMultiInstCnctStatus(Enum):
	"""5 Members, CERRor ... TDISconnecting"""
	CERRor = 0
	CONNected = 1
	DISConnected = 2
	TCONnencting = 3
	TDISconnecting = 4


# noinspection SpellCheckingInspection
class AregMultiInstMode(Enum):
	"""3 Members, OFF ... SECondary"""
	OFF = 0
	PRIMary = 1
	SECondary = 2


# noinspection SpellCheckingInspection
class AregPlEd(Enum):
	"""4 Members, ERRor ... WARNing"""
	ERRor = 0
	INACtive = 1
	OK = 2
	WARNing = 3


# noinspection SpellCheckingInspection
class AregPowSens(Enum):
	"""5 Members, SEN1 ... UDEFined"""
	SEN1 = 0
	SEN2 = 1
	SEN3 = 2
	SEN4 = 3
	UDEFined = 4


# noinspection SpellCheckingInspection
class AregRadarPowIndicator(Enum):
	"""4 Members, BAD ... WEAK"""
	BAD = 0
	GOOD = 1
	OFF = 2
	WEAK = 3


# noinspection SpellCheckingInspection
class ByteOrder(Enum):
	"""2 Members, NORMal ... SWAPped"""
	NORMal = 0
	SWAPped = 1


# noinspection SpellCheckingInspection
class CalDataMode(Enum):
	"""2 Members, CUSTomer ... FACTory"""
	CUSTomer = 0
	FACTory = 1


# noinspection SpellCheckingInspection
class CalDataUpdate(Enum):
	"""6 Members, BBFRC ... RFFRC"""
	BBFRC = 0
	FREQuency = 1
	IALL = 2
	LEVel = 3
	LEVForced = 4
	RFFRC = 5


# noinspection SpellCheckingInspection
class Colour(Enum):
	"""4 Members, GREen ... YELLow"""
	GREen = 0
	NONE = 1
	RED = 2
	YELLow = 3


# noinspection SpellCheckingInspection
class DevExpFormat(Enum):
	"""4 Members, CGPRedefined ... XML"""
	CGPRedefined = 0
	CGUSer = 1
	SCPI = 2
	XML = 3


# noinspection SpellCheckingInspection
class DispKeybLockMode(Enum):
	"""5 Members, DISabled ... VNConly"""
	DISabled = 0
	DONLy = 1
	ENABled = 2
	TOFF = 3
	VNConly = 4


# noinspection SpellCheckingInspection
class ErFpowSensMapping(Enum):
	"""9 Members, SENS1 ... UNMapped"""
	SENS1 = 0
	SENS2 = 1
	SENS3 = 2
	SENS4 = 3
	SENSor1 = 4
	SENSor2 = 5
	SENSor3 = 6
	SENSor4 = 7
	UNMapped = 8


# noinspection SpellCheckingInspection
class FormData(Enum):
	"""2 Members, ASCii ... PACKed"""
	ASCii = 0
	PACKed = 1


# noinspection SpellCheckingInspection
class FormStatReg(Enum):
	"""4 Members, ASCii ... OCTal"""
	ASCii = 0
	BINary = 1
	HEXadecimal = 2
	OCTal = 3


# noinspection SpellCheckingInspection
class HardCopyImageFormat(Enum):
	"""4 Members, BMP ... XPM"""
	BMP = 0
	JPG = 1
	PNG = 2
	XPM = 3


# noinspection SpellCheckingInspection
class HardCopyRegion(Enum):
	"""2 Members, ALL ... DIALog"""
	ALL = 0
	DIALog = 1


# noinspection SpellCheckingInspection
class HilDataReceive(Enum):
	"""3 Members, NOData ... RECeived"""
	NOData = 0
	NOTHil = 1
	RECeived = 2


# noinspection SpellCheckingInspection
class IecDevId(Enum):
	"""2 Members, AUTO ... USER"""
	AUTO = 0
	USER = 1


# noinspection SpellCheckingInspection
class IecTermMode(Enum):
	"""2 Members, EOI ... STANdard"""
	EOI = 0
	STANdard = 1


# noinspection SpellCheckingInspection
class InclExcl(Enum):
	"""2 Members, EXCLude ... INCLude"""
	EXCLude = 0
	INCLude = 1


# noinspection SpellCheckingInspection
class KbLayout(Enum):
	"""20 Members, CHINese ... SWEDish"""
	CHINese = 0
	DANish = 1
	DUTBe = 2
	DUTCh = 3
	ENGLish = 4
	ENGUK = 5
	ENGUS = 6
	FINNish = 7
	FREBe = 8
	FRECa = 9
	FRENch = 10
	GERMan = 11
	ITALian = 12
	JAPanese = 13
	KORean = 14
	NORWegian = 15
	PORTuguese = 16
	RUSSian = 17
	SPANish = 18
	SWEDish = 19


# noinspection SpellCheckingInspection
class NetMode(Enum):
	"""2 Members, AUTO ... STATic"""
	AUTO = 0
	STATic = 1


# noinspection SpellCheckingInspection
class OsetupBw(Enum):
	"""4 Members, BW1G ... SERVice"""
	BW1G = 0
	BW2G = 1
	BW5G = 2
	SERVice = 3


# noinspection SpellCheckingInspection
class OsetupDataSource(Enum):
	"""2 Members, HIL ... SCENario"""
	HIL = 0
	SCENario = 1


# noinspection SpellCheckingInspection
class OsetupHilProtocol(Enum):
	"""4 Members, DCP ... ZMQ"""
	DCP = 0
	UDP = 1
	UDPR = 2
	ZMQ = 3


# noinspection SpellCheckingInspection
class OsetupMode(Enum):
	"""2 Members, DYNamic ... STATic"""
	DYNamic = 0
	STATic = 1


# noinspection SpellCheckingInspection
class OsetupObjRef(Enum):
	"""2 Members, MAPPed ... ORIGin"""
	MAPPed = 0
	ORIGin = 1


# noinspection SpellCheckingInspection
class Parity(Enum):
	"""3 Members, EVEN ... ODD"""
	EVEN = 0
	NONE = 1
	ODD = 2


# noinspection SpellCheckingInspection
class PowSensDisplayPriority(Enum):
	"""2 Members, AVERage ... PEAK"""
	AVERage = 0
	PEAK = 1


# noinspection SpellCheckingInspection
class PowSensFiltType(Enum):
	"""3 Members, AUTO ... USER"""
	AUTO = 0
	NSRatio = 1
	USER = 2


# noinspection SpellCheckingInspection
class PowSensSource(Enum):
	"""4 Members, A ... USER"""
	A = 0
	B = 1
	RF = 2
	USER = 3


# noinspection SpellCheckingInspection
class RecScpiCmdMode(Enum):
	"""4 Members, AUTO ... OFF"""
	AUTO = 0
	DAUTo = 1
	MANual = 2
	OFF = 3


# noinspection SpellCheckingInspection
class RoscBandWidtExt(Enum):
	"""2 Members, NARRow ... WIDE"""
	NARRow = 0
	WIDE = 1


# noinspection SpellCheckingInspection
class RoscFreqExt(Enum):
	"""3 Members, _10MHZ ... _5MHZ"""
	_10MHZ = 0
	_13MHZ = 1
	_5MHZ = 2


# noinspection SpellCheckingInspection
class RoscOutpFreqModeSmbb(Enum):
	"""3 Members, DER10M ... OFF"""
	DER10M = 0
	LOOPthrough = 1
	OFF = 2


# noinspection SpellCheckingInspection
class RoscSourSetup(Enum):
	"""3 Members, ELOop ... INTernal"""
	ELOop = 0
	EXTernal = 1
	INTernal = 2


# noinspection SpellCheckingInspection
class Rs232BdRate(Enum):
	"""7 Members, _115200 ... _9600"""
	_115200 = 0
	_19200 = 1
	_2400 = 2
	_38400 = 3
	_4800 = 4
	_57600 = 5
	_9600 = 6


# noinspection SpellCheckingInspection
class Rs232StopBits(Enum):
	"""2 Members, _1 ... _2"""
	_1 = 0
	_2 = 1


# noinspection SpellCheckingInspection
class ScenarioReplyMode(Enum):
	"""2 Members, LOOP ... SINGle"""
	LOOP = 0
	SINGle = 1


# noinspection SpellCheckingInspection
class ScenarioStatus(Enum):
	"""2 Members, RUNNing ... STOPped"""
	RUNNing = 0
	STOPped = 1


# noinspection SpellCheckingInspection
class SelftLev(Enum):
	"""3 Members, CUSTomer ... SERVice"""
	CUSTomer = 0
	PRODuction = 1
	SERVice = 2


# noinspection SpellCheckingInspection
class SelftLevWrite(Enum):
	"""4 Members, CUSTomer ... SERVice"""
	CUSTomer = 0
	NONE = 1
	PRODuction = 2
	SERVice = 3


# noinspection SpellCheckingInspection
class SlopeType(Enum):
	"""2 Members, NEGative ... POSitive"""
	NEGative = 0
	POSitive = 1


# noinspection SpellCheckingInspection
class StateExtended(Enum):
	"""3 Members, DEFault ... ON"""
	DEFault = 0
	OFF = 1
	ON = 2


# noinspection SpellCheckingInspection
class Test(Enum):
	"""4 Members, _0 ... STOPped"""
	_0 = 0
	_1 = 1
	RUNning = 2
	STOPped = 3


# noinspection SpellCheckingInspection
class TestCalSelected(Enum):
	"""2 Members, _0 ... _1"""
	_0 = 0
	_1 = 1


# noinspection SpellCheckingInspection
class UnitAngle(Enum):
	"""3 Members, DEGree ... RADian"""
	DEGree = 0
	DEGRee = 1
	RADian = 2


# noinspection SpellCheckingInspection
class UnitAngleAreg(Enum):
	"""2 Members, DEGree ... RADian"""
	DEGree = 0
	RADian = 1


# noinspection SpellCheckingInspection
class UnitLengthAreg(Enum):
	"""3 Members, CM ... M"""
	CM = 0
	FT = 1
	M = 2


# noinspection SpellCheckingInspection
class UnitPower(Enum):
	"""3 Members, DBM ... V"""
	DBM = 0
	DBUV = 1
	V = 2


# noinspection SpellCheckingInspection
class UnitPowSens(Enum):
	"""3 Members, DBM ... WATT"""
	DBM = 0
	DBUV = 1
	WATT = 2


# noinspection SpellCheckingInspection
class UnitRcsAreg(Enum):
	"""2 Members, DBSM ... SM"""
	DBSM = 0
	SM = 1


# noinspection SpellCheckingInspection
class UnitShiftAreg(Enum):
	"""3 Members, HZ ... MHZ"""
	HZ = 0
	KHZ = 1
	MHZ = 2


# noinspection SpellCheckingInspection
class UnitSpeed(Enum):
	"""4 Members, KMH ... NMPH"""
	KMH = 0
	MPH = 1
	MPS = 2
	NMPH = 3


# noinspection SpellCheckingInspection
class UnitSpeedAreg(Enum):
	"""3 Members, KMH ... MPS"""
	KMH = 0
	MPH = 1
	MPS = 2


# noinspection SpellCheckingInspection
class UpdPolicyMode(Enum):
	"""3 Members, CONFirm ... STRict"""
	CONFirm = 0
	IGNore = 1
	STRict = 2



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AttenuationCls:
	"""Attenuation commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("attenuation", core, parent)

	def set(self, areg_cable_corr_at: float, qatFrontent=repcap.QatFrontent.Default, connector=repcap.Connector.Default, rxIndex=repcap.RxIndex.Default) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:QAT<CH>:CABLecorr:CONNector<DI>:RX<ST>:USER:ATTenuation \n
		Snippet: driver.source.areGenerator.frontend.qat.cableCorr.connector.rx.user.attenuation.set(areg_cable_corr_at = 1.0, qatFrontent = repcap.QatFrontent.Default, connector = repcap.Connector.Default, rxIndex = repcap.RxIndex.Default) \n
		No command help available \n
			:param areg_cable_corr_at: float Range: 0 to 50
			:param qatFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Qat')
			:param connector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Connector')
			:param rxIndex: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Rx')
		"""
		param = Conversions.decimal_value_to_str(areg_cable_corr_at)
		qatFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(qatFrontent, repcap.QatFrontent)
		connector_cmd_val = self._cmd_group.get_repcap_cmd_value(connector, repcap.Connector)
		rxIndex_cmd_val = self._cmd_group.get_repcap_cmd_value(rxIndex, repcap.RxIndex)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:FRONtend:QAT{qatFrontent_cmd_val}:CABLecorr:CONNector{connector_cmd_val}:RX{rxIndex_cmd_val}:USER:ATTenuation {param}')

	def get(self, qatFrontent=repcap.QatFrontent.Default, connector=repcap.Connector.Default, rxIndex=repcap.RxIndex.Default) -> float:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:QAT<CH>:CABLecorr:CONNector<DI>:RX<ST>:USER:ATTenuation \n
		Snippet: value: float = driver.source.areGenerator.frontend.qat.cableCorr.connector.rx.user.attenuation.get(qatFrontent = repcap.QatFrontent.Default, connector = repcap.Connector.Default, rxIndex = repcap.RxIndex.Default) \n
		No command help available \n
			:param qatFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Qat')
			:param connector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Connector')
			:param rxIndex: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Rx')
			:return: areg_cable_corr_at: float Range: 0 to 50"""
		qatFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(qatFrontent, repcap.QatFrontent)
		connector_cmd_val = self._cmd_group.get_repcap_cmd_value(connector, repcap.Connector)
		rxIndex_cmd_val = self._cmd_group.get_repcap_cmd_value(rxIndex, repcap.RxIndex)
		response = self._core.io.query_str(f'SOURce<HwInstance>:AREGenerator:FRONtend:QAT{qatFrontent_cmd_val}:CABLecorr:CONNector{connector_cmd_val}:RX{rxIndex_cmd_val}:USER:ATTenuation?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SecondaryCls:
	"""Secondary commands group definition. 5 total commands, 3 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("secondary", core, parent)

	@property
	def add(self):
		"""add commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_add'):
			from .Add import AddCls
			self._add = AddCls(self._core, self._cmd_group)
		return self._add

	@property
	def connection(self):
		"""connection commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_connection'):
			from .Connection import ConnectionCls
			self._connection = ConnectionCls(self._core, self._cmd_group)
		return self._connection

	@property
	def remove(self):
		"""remove commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_remove'):
			from .Remove import RemoveCls
			self._remove = RemoveCls(self._core, self._cmd_group)
		return self._remove

	def get_hostname(self) -> str:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:MULTiinstrument:SECondary:HOSTname \n
		Snippet: value: str = driver.source.areGenerator.osetup.multiInstrument.secondary.get_hostname() \n
		No command help available \n
			:return: hostname: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:OSETup:MULTiinstrument:SECondary:HOSTname?')
		return trim_str_response(response)

	def set_hostname(self, hostname: str) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:MULTiinstrument:SECondary:HOSTname \n
		Snippet: driver.source.areGenerator.osetup.multiInstrument.secondary.set_hostname(hostname = '1') \n
		No command help available \n
			:param hostname: No help available
		"""
		param = Conversions.value_to_quoted_str(hostname)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:OSETup:MULTiinstrument:SECondary:HOSTname {param}')

	def get_value(self) -> str:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:MULTiinstrument:SECondary \n
		Snippet: value: str = driver.source.areGenerator.osetup.multiInstrument.secondary.get_value() \n
		No command help available \n
			:return: sec_addr: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:OSETup:MULTiinstrument:SECondary?')
		return trim_str_response(response)

	def set_value(self, sec_addr: str) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:MULTiinstrument:SECondary \n
		Snippet: driver.source.areGenerator.osetup.multiInstrument.secondary.set_value(sec_addr = '1') \n
		No command help available \n
			:param sec_addr: No help available
		"""
		param = Conversions.value_to_quoted_str(sec_addr)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:OSETup:MULTiinstrument:SECondary {param}')

	def clone(self) -> 'SecondaryCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SecondaryCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PriorityCls:
	"""Priority commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("priority", core, parent)

	def set(self, priority: enums.PowSensDisplayPriority, channel=repcap.Channel.Default) -> None:
		"""SCPI: SENSe<CH>:[POWer]:DISPlay:PERManent:PRIority \n
		Snippet: driver.sense.power.display.permanent.priority.set(priority = enums.PowSensDisplayPriority.AVERage, channel = repcap.Channel.Default) \n
		Selects average or peak power for permanent display. \n
			:param priority: AVERage| PEAK
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sense')
		"""
		param = Conversions.enum_scalar_to_str(priority, enums.PowSensDisplayPriority)
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SENSe{channel_cmd_val}:POWer:DISPlay:PERManent:PRIority {param}')

	# noinspection PyTypeChecker
	def get(self, channel=repcap.Channel.Default) -> enums.PowSensDisplayPriority:
		"""SCPI: SENSe<CH>:[POWer]:DISPlay:PERManent:PRIority \n
		Snippet: value: enums.PowSensDisplayPriority = driver.sense.power.display.permanent.priority.get(channel = repcap.Channel.Default) \n
		Selects average or peak power for permanent display. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sense')
			:return: priority: AVERage| PEAK"""
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SENSe{channel_cmd_val}:POWer:DISPlay:PERManent:PRIority?')
		return Conversions.str_to_scalar_enum(response, enums.PowSensDisplayPriority)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OsetupCls:
	"""Osetup commands group definition. 18 total commands, 3 Subgroups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("osetup", core, parent)

	@property
	def apply(self):
		"""apply commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_apply'):
			from .Apply import ApplyCls
			self._apply = ApplyCls(self._core, self._cmd_group)
		return self._apply

	@property
	def bw(self):
		"""bw commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_bw'):
			from .Bw import BwCls
			self._bw = BwCls(self._core, self._cmd_group)
		return self._bw

	@property
	def multiInstrument(self):
		"""multiInstrument commands group. 2 Sub-classes, 2 commands."""
		if not hasattr(self, '_multiInstrument'):
			from .MultiInstrument import MultiInstrumentCls
			self._multiInstrument = MultiInstrumentCls(self._core, self._cmd_group)
		return self._multiInstrument

	def get_hostname(self) -> str:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:HOSTname \n
		Snippet: value: str = driver.source.areGenerator.osetup.get_hostname() \n
		No command help available \n
			:return: areg_osetup_ip_address: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:OSETup:HOSTname?')
		return trim_str_response(response)

	def set_hostname(self, areg_osetup_ip_address: str) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:HOSTname \n
		Snippet: driver.source.areGenerator.osetup.set_hostname(areg_osetup_ip_address = '1') \n
		No command help available \n
			:param areg_osetup_ip_address: No help available
		"""
		param = Conversions.value_to_quoted_str(areg_osetup_ip_address)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:OSETup:HOSTname {param}')

	def get_ip_address(self) -> str:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:IPADdress \n
		Snippet: value: str = driver.source.areGenerator.osetup.get_ip_address() \n
		No command help available \n
			:return: areg_osetup_ip_address: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:OSETup:IPADdress?')
		return trim_str_response(response)

	def set_ip_address(self, areg_osetup_ip_address: str) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:IPADdress \n
		Snippet: driver.source.areGenerator.osetup.set_ip_address(areg_osetup_ip_address = '1') \n
		No command help available \n
			:param areg_osetup_ip_address: No help available
		"""
		param = Conversions.value_to_quoted_str(areg_osetup_ip_address)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:OSETup:IPADdress {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.OsetupMode:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:MODE \n
		Snippet: value: enums.OsetupMode = driver.source.areGenerator.osetup.get_mode() \n
		No command help available \n
			:return: areg_oset_mode: STATic| DYNamic
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:OSETup:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.OsetupMode)

	def set_mode(self, areg_oset_mode: enums.OsetupMode) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:MODE \n
		Snippet: driver.source.areGenerator.osetup.set_mode(areg_oset_mode = enums.OsetupMode.DYNamic) \n
		No command help available \n
			:param areg_oset_mode: STATic| DYNamic
		"""
		param = Conversions.enum_scalar_to_str(areg_oset_mode, enums.OsetupMode)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:OSETup:MODE {param}')

	def get_port(self) -> int:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:PORT \n
		Snippet: value: int = driver.source.areGenerator.osetup.get_port() \n
		No command help available \n
			:return: areg_oset_port: integer Range: 0 to 64000
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:OSETup:PORT?')
		return Conversions.str_to_int(response)

	def set_port(self, areg_oset_port: int) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:PORT \n
		Snippet: driver.source.areGenerator.osetup.set_port(areg_oset_port = 1) \n
		No command help available \n
			:param areg_oset_port: integer Range: 0 to 64000
		"""
		param = Conversions.decimal_value_to_str(areg_oset_port)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:OSETup:PORT {param}')

	# noinspection PyTypeChecker
	def get_protocol(self) -> enums.OsetupHilProtocol:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:PROTocol \n
		Snippet: value: enums.OsetupHilProtocol = driver.source.areGenerator.osetup.get_protocol() \n
		No command help available \n
			:return: areg_oset_protocol: ZMQ| DCP
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:OSETup:PROTocol?')
		return Conversions.str_to_scalar_enum(response, enums.OsetupHilProtocol)

	def set_protocol(self, areg_oset_protocol: enums.OsetupHilProtocol) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:PROTocol \n
		Snippet: driver.source.areGenerator.osetup.set_protocol(areg_oset_protocol = enums.OsetupHilProtocol.DCP) \n
		No command help available \n
			:param areg_oset_protocol: ZMQ| DCP
		"""
		param = Conversions.enum_scalar_to_str(areg_oset_protocol, enums.OsetupHilProtocol)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:OSETup:PROTocol {param}')

	# noinspection PyTypeChecker
	def get_reference(self) -> enums.OsetupObjRef:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:REFerence \n
		Snippet: value: enums.OsetupObjRef = driver.source.areGenerator.osetup.get_reference() \n
		No command help available \n
			:return: areg_osetup_ref: ORIGin| MAPPed
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:OSETup:REFerence?')
		return Conversions.str_to_scalar_enum(response, enums.OsetupObjRef)

	def set_reference(self, areg_osetup_ref: enums.OsetupObjRef) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:REFerence \n
		Snippet: driver.source.areGenerator.osetup.set_reference(areg_osetup_ref = enums.OsetupObjRef.MAPPed) \n
		No command help available \n
			:param areg_osetup_ref: ORIGin| MAPPed
		"""
		param = Conversions.enum_scalar_to_str(areg_osetup_ref, enums.OsetupObjRef)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:OSETup:REFerence {param}')

	# noinspection PyTypeChecker
	def get_source(self) -> enums.OsetupDataSource:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:SOURce \n
		Snippet: value: enums.OsetupDataSource = driver.source.areGenerator.osetup.get_source() \n
		No command help available \n
			:return: areg_oset_source: SCENario| HIL
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:OSETup:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.OsetupDataSource)

	def set_source(self, areg_oset_source: enums.OsetupDataSource) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:SOURce \n
		Snippet: driver.source.areGenerator.osetup.set_source(areg_oset_source = enums.OsetupDataSource.HIL) \n
		No command help available \n
			:param areg_oset_source: SCENario| HIL
		"""
		param = Conversions.enum_scalar_to_str(areg_oset_source, enums.OsetupDataSource)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:OSETup:SOURce {param}')

	def clone(self) -> 'OsetupCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = OsetupCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FileCls:
	"""File commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("file", core, parent)

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:AREGenerator:SCENario:FILE:CATalog \n
		Snippet: value: List[str] = driver.source.areGenerator.scenario.file.get_catalog() \n
		No command help available \n
			:return: areg_scenario_file_cat: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:SCENario:FILE:CATalog?')
		return Conversions.str_to_str_list(response)

	def get_value(self) -> str:
		"""SCPI: [SOURce<HW>]:AREGenerator:SCENario:FILE \n
		Snippet: value: str = driver.source.areGenerator.scenario.file.get_value() \n
		No command help available \n
			:return: scenario_file: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:SCENario:FILE?')
		return trim_str_response(response)

	def set_value(self, scenario_file: str) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:SCENario:FILE \n
		Snippet: driver.source.areGenerator.scenario.file.set_value(scenario_file = '1') \n
		No command help available \n
			:param scenario_file: string
		"""
		param = Conversions.value_to_quoted_str(scenario_file)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:SCENario:FILE {param}')
